%%
% This code accompanies the paper:
%
% "A Simple and Effective Relevance-Based Point Sampling for 3D Shapes"
% E. Rodola, A. Albarelli, D. Cremers, A. Torsello
% Pattern Recognition Letters, 59(1), pp 41-47, 2015
%
% Please cite the paper above if you use this code.
%
% Written by Emanuele Rodola.
%
addpath('./src/');

load('./bunny.mat')

% plot against dot threshold (T)
vals = [0.85 0.93 0.96 0.99];
figure, colormap(jet)
for v=1:length(vals)
    areas = calc_relevance(M.VERT', M.TRIV', M.N', ones(M.n,1), vals(v), 6*M.res);
    relevance = 1./areas';
    subplot(1,4,v), plot_scalar_map(M, log(relevance)), axis off, title(sprintf('%.2f',vals(v)))
    caxis([-4.7 0])
end

% plot against selectivity (k)
vals = [0.25 0.5 1 2];
figure, colormap(jet)
for v=1:length(vals)
    areas = calc_relevance(M.VERT', M.TRIV', M.N', ones(M.n,1), 0.96, 6*M.res);
    relevance = (1./areas').^vals(v);
    subplot(1,4,v), plot_scalar_map(M, log(relevance)), axis off, title(sprintf('%.2f',vals(v)))
    caxis([-4.7 0])
end
